"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DidDocument = void 0;
const class_transformer_1 = require("class-transformer");
const class_validator_1 = require("class-validator");
const JsonTransformer_1 = require("../../../utils/JsonTransformer");
const service_1 = require("./service");
const verificationMethod_1 = require("./verificationMethod");
class DidDocument {
    constructor(options) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        this.context = ['https://w3id.org/did/v1'];
        this.alsoKnownAs = [];
        this.controller = [];
        this.verificationMethod = [];
        this.service = [];
        this.authentication = [];
        this.assertionMethod = [];
        this.keyAgreement = [];
        this.capabilityInvocation = [];
        this.capabilityDelegation = [];
        if (options) {
            this.context = (_a = options.context) !== null && _a !== void 0 ? _a : this.context;
            this.id = options.id;
            this.alsoKnownAs = (_b = options.alsoKnownAs) !== null && _b !== void 0 ? _b : this.alsoKnownAs;
            this.controller = (_c = options.controller) !== null && _c !== void 0 ? _c : this.controller;
            this.verificationMethod = (_d = options.verificationMethod) !== null && _d !== void 0 ? _d : this.verificationMethod;
            this.service = (_e = options.service) !== null && _e !== void 0 ? _e : this.service;
            this.authentication = (_f = options.authentication) !== null && _f !== void 0 ? _f : this.authentication;
            this.assertionMethod = (_g = options.assertionMethod) !== null && _g !== void 0 ? _g : this.assertionMethod;
            this.keyAgreement = (_h = options.keyAgreement) !== null && _h !== void 0 ? _h : this.keyAgreement;
            this.capabilityInvocation = (_j = options.capabilityInvocation) !== null && _j !== void 0 ? _j : this.capabilityInvocation;
            this.capabilityDelegation = (_k = options.capabilityDelegation) !== null && _k !== void 0 ? _k : this.capabilityDelegation;
        }
    }
    dereferenceKey(keyId) {
        // TODO: once we use JSON-LD we should use that to resolve references in did documents.
        // for now we check whether the key id ends with the keyId.
        // so if looking for #123 and key.id is did:key:123#123, it is valid. But #123 as key.id is also valid
        const verificationMethod = this.verificationMethod.find((key) => key.id.endsWith(keyId));
        if (!verificationMethod) {
            throw new Error(`Unable to locate verification with id '${keyId}'`);
        }
        return verificationMethod;
    }
    /**
     * Returns all of the service endpoints matching the given type.
     *
     * @param type The type of service(s) to query.
     */
    getServicesByType(type) {
        return this.service.filter((service) => service.type === type);
    }
    /**
     * Returns all of the service endpoints matching the given class
     *
     * @param classType The class to query services.
     */
    getServicesByClassType(classType) {
        return this.service.filter((service) => service instanceof classType);
    }
    /**
     * Get all DIDComm services ordered by priority descending. This means the highest
     * priority will be the first entry.
     */
    get didCommServices() {
        const didCommServiceTypes = [service_1.IndyAgentService.type, service_1.DidCommService.type];
        const services = this.service.filter((service) => didCommServiceTypes.includes(service.type));
        // Sort services based on indicated priority
        return services.sort((a, b) => b.priority - a.priority);
    }
    get recipientKeys() {
        // Get a `recipientKeys` entries from the did document
        return this.didCommServices.reduce((recipientKeys, service) => recipientKeys.concat(service.recipientKeys), []);
    }
    toJSON() {
        return JsonTransformer_1.JsonTransformer.toJSON(this);
    }
}
__decorate([
    class_transformer_1.Expose({ name: '@context' }),
    class_validator_1.IsArray(),
    class_transformer_1.Transform((o) => (typeof o.value === 'string' ? [o.value] : o.value), { toClassOnly: true }),
    __metadata("design:type", Object)
], DidDocument.prototype, "context", void 0);
__decorate([
    class_validator_1.IsString(),
    __metadata("design:type", String)
], DidDocument.prototype, "id", void 0);
__decorate([
    class_validator_1.IsArray(),
    class_validator_1.IsString({ each: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "alsoKnownAs", void 0);
__decorate([
    class_validator_1.IsArray(),
    class_validator_1.IsString({ each: true }),
    class_transformer_1.Transform((o) => (typeof o.value === 'string' ? [o.value] : o.value), { toClassOnly: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "controller", void 0);
__decorate([
    class_validator_1.IsArray(),
    class_validator_1.ValidateNested({ each: true }),
    class_transformer_1.Type(() => verificationMethod_1.VerificationMethod),
    __metadata("design:type", Array)
], DidDocument.prototype, "verificationMethod", void 0);
__decorate([
    class_validator_1.IsArray(),
    service_1.ServiceTransformer(),
    __metadata("design:type", Array)
], DidDocument.prototype, "service", void 0);
__decorate([
    class_validator_1.IsArray(),
    verificationMethod_1.VerificationMethodTransformer(),
    verificationMethod_1.IsStringOrVerificationMethod({ each: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "authentication", void 0);
__decorate([
    class_validator_1.IsArray(),
    verificationMethod_1.VerificationMethodTransformer(),
    verificationMethod_1.IsStringOrVerificationMethod({ each: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "assertionMethod", void 0);
__decorate([
    class_validator_1.IsArray(),
    verificationMethod_1.VerificationMethodTransformer(),
    verificationMethod_1.IsStringOrVerificationMethod({ each: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "keyAgreement", void 0);
__decorate([
    class_validator_1.IsArray(),
    verificationMethod_1.VerificationMethodTransformer(),
    verificationMethod_1.IsStringOrVerificationMethod({ each: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "capabilityInvocation", void 0);
__decorate([
    class_validator_1.IsArray(),
    verificationMethod_1.VerificationMethodTransformer(),
    verificationMethod_1.IsStringOrVerificationMethod({ each: true }),
    __metadata("design:type", Array)
], DidDocument.prototype, "capabilityDelegation", void 0);
exports.DidDocument = DidDocument;
//# sourceMappingURL=DidDocument.js.map