"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DidDocumentBuilder = void 0;
const DidDocument_1 = require("./DidDocument");
const verificationMethod_1 = require("./verificationMethod");
class DidDocumentBuilder {
    constructor(id) {
        this.didDocument = new DidDocument_1.DidDocument({
            id,
        });
    }
    addContext(context) {
        this.didDocument.context = [...this.didDocument.context, context];
        return this;
    }
    addService(service) {
        this.didDocument.service = [...this.didDocument.service, service];
        return this;
    }
    addVerificationMethod(verificationMethod) {
        this.didDocument.verificationMethod = [
            ...this.didDocument.verificationMethod,
            verificationMethod instanceof verificationMethod_1.VerificationMethod
                ? verificationMethod
                : new verificationMethod_1.VerificationMethod(verificationMethod),
        ];
        return this;
    }
    addAuthentication(authentication) {
        const verificationMethod = authentication instanceof verificationMethod_1.VerificationMethod || typeof authentication === 'string'
            ? authentication
            : new verificationMethod_1.VerificationMethod(authentication);
        this.didDocument.authentication = [...this.didDocument.authentication, verificationMethod];
        return this;
    }
    addAssertionMethod(assertionMethod) {
        const verificationMethod = assertionMethod instanceof verificationMethod_1.VerificationMethod || typeof assertionMethod === 'string'
            ? assertionMethod
            : new verificationMethod_1.VerificationMethod(assertionMethod);
        this.didDocument.assertionMethod = [...this.didDocument.assertionMethod, verificationMethod];
        return this;
    }
    addCapabilityDelegation(capabilityDelegation) {
        const verificationMethod = capabilityDelegation instanceof verificationMethod_1.VerificationMethod || typeof capabilityDelegation === 'string'
            ? capabilityDelegation
            : new verificationMethod_1.VerificationMethod(capabilityDelegation);
        this.didDocument.capabilityDelegation = [...this.didDocument.capabilityDelegation, verificationMethod];
        return this;
    }
    addCapabilityInvocation(capabilityInvocation) {
        const verificationMethod = capabilityInvocation instanceof verificationMethod_1.VerificationMethod || typeof capabilityInvocation === 'string'
            ? capabilityInvocation
            : new verificationMethod_1.VerificationMethod(capabilityInvocation);
        this.didDocument.capabilityInvocation = [...this.didDocument.capabilityInvocation, verificationMethod];
        return this;
    }
    addKeyAgreement(keyAgreement) {
        const verificationMethod = keyAgreement instanceof verificationMethod_1.VerificationMethod || typeof keyAgreement === 'string'
            ? keyAgreement
            : new verificationMethod_1.VerificationMethod(keyAgreement);
        this.didDocument.keyAgreement = [...this.didDocument.keyAgreement, verificationMethod];
        return this;
    }
    build() {
        return this.didDocument;
    }
}
exports.DidDocumentBuilder = DidDocumentBuilder;
//# sourceMappingURL=DidDocumentBuilder.js.map