"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.keyDidBls12381g1g2 = exports.getBls12381g1g2DidDoc = exports.getBls12381g1g2VerificationMethod = void 0;
const crypto_1 = require("../../../../crypto");
const DidDocumentBuilder_1 = require("../DidDocumentBuilder");
const Key_1 = require("../Key");
const bls12381g1_1 = require("./bls12381g1");
const bls12381g2_1 = require("./bls12381g2");
function getBls12381g1g2VerificationMethod(did, key) {
    const g1PublicKey = key.publicKey.slice(0, 48);
    const g2PublicKey = key.publicKey.slice(48);
    const bls12381g1Key = Key_1.Key.fromPublicKey(g1PublicKey, crypto_1.KeyType.Bls12381g1);
    const bls12381g2Key = Key_1.Key.fromPublicKey(g2PublicKey, crypto_1.KeyType.Bls12381g2);
    const bls12381g1VerificationMethod = bls12381g1_1.getBls12381g1VerificationMethod(did, bls12381g1Key);
    const bls12381g2VerificationMethod = bls12381g2_1.getBls12381g2VerificationMethod(did, bls12381g2Key);
    return [bls12381g1VerificationMethod, bls12381g2VerificationMethod];
}
exports.getBls12381g1g2VerificationMethod = getBls12381g1g2VerificationMethod;
function getBls12381g1g2DidDoc(did, key) {
    const verificationMethods = getBls12381g1g2VerificationMethod(did, key);
    const didDocumentBuilder = new DidDocumentBuilder_1.DidDocumentBuilder(did);
    for (const verificationMethod of verificationMethods) {
        didDocumentBuilder
            .addVerificationMethod(verificationMethod)
            .addAuthentication(verificationMethod.id)
            .addAssertionMethod(verificationMethod.id)
            .addCapabilityDelegation(verificationMethod.id)
            .addCapabilityInvocation(verificationMethod.id);
    }
    return didDocumentBuilder.build();
}
exports.getBls12381g1g2DidDoc = getBls12381g1g2DidDoc;
exports.keyDidBls12381g1g2 = {
    supportedVerificationMethodTypes: [],
    getDidDocument: getBls12381g1g2DidDoc,
    getVerificationMethods: getBls12381g1g2VerificationMethod,
    getKeyFromVerificationMethod: () => {
        throw new Error('Not supported for bls12381g1g2 key');
    },
};
//# sourceMappingURL=bls12381g1g2.js.map