"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertPublicKeyToX25519 = exports.keyDidEd25519 = exports.getEd25519DidDoc = exports.getEd25519VerificationMethod = void 0;
const ed25519_1 = require("@stablelib/ed25519");
Object.defineProperty(exports, "convertPublicKeyToX25519", { enumerable: true, get: function () { return ed25519_1.convertPublicKeyToX25519; } });
const crypto_1 = require("../../../../crypto");
const Key_1 = require("../Key");
const getSignatureKeyBase_1 = require("./getSignatureKeyBase");
const x25519_1 = require("./x25519");
const VERIFICATION_METHOD_TYPE_ED25519_VERIFICATION_KEY_2018 = 'Ed25519VerificationKey2018';
function getEd25519VerificationMethod({ key, id, controller }) {
    return {
        id,
        type: VERIFICATION_METHOD_TYPE_ED25519_VERIFICATION_KEY_2018,
        controller,
        publicKeyBase58: key.publicKeyBase58,
    };
}
exports.getEd25519VerificationMethod = getEd25519VerificationMethod;
function getEd25519DidDoc(did, key) {
    const verificationMethod = getEd25519VerificationMethod({ id: `${did}#${key.fingerprint}`, key, controller: did });
    const publicKeyX25519 = ed25519_1.convertPublicKeyToX25519(key.publicKey);
    const didKeyX25519 = Key_1.Key.fromPublicKey(publicKeyX25519, crypto_1.KeyType.X25519);
    const x25519VerificationMethod = x25519_1.getX25519VerificationMethod({
        id: `${did}#${didKeyX25519.fingerprint}`,
        key: didKeyX25519,
        controller: did,
    });
    const didDocBuilder = getSignatureKeyBase_1.getSignatureKeyBase({ did, key, verificationMethod });
    didDocBuilder
        .addContext('https://w3id.org/security/suites/ed25519-2018/v1')
        .addContext('https://w3id.org/security/suites/x25519-2019/v1')
        .addKeyAgreement(x25519VerificationMethod);
    return didDocBuilder.build();
}
exports.getEd25519DidDoc = getEd25519DidDoc;
exports.keyDidEd25519 = {
    supportedVerificationMethodTypes: [VERIFICATION_METHOD_TYPE_ED25519_VERIFICATION_KEY_2018],
    getDidDocument: getEd25519DidDoc,
    getVerificationMethods: (did, key) => [
        getEd25519VerificationMethod({ id: `${did}#${key.fingerprint}`, key, controller: did }),
    ],
    getKeyFromVerificationMethod: (verificationMethod) => {
        if (verificationMethod.type !== VERIFICATION_METHOD_TYPE_ED25519_VERIFICATION_KEY_2018 ||
            !verificationMethod.publicKeyBase58) {
            throw new Error('Invalid verification method passed');
        }
        return Key_1.Key.fromPublicKeyBase58(verificationMethod.publicKeyBase58, crypto_1.KeyType.Ed25519);
    },
};
//# sourceMappingURL=ed25519.js.map